@@ -143,6 +143,7 @@ ENUM_BEGIN(KwsAtom)
     ENUM(_KDE_NET_WM_WINDOW_TYPE_TOPMENU),
     ENUM(_KDE_NET_WM_WINDOW_TYPE_ON_SCREEN_DISPLAY),
     ENUM(_KDE_NET_WM_WINDOW_TYPE_CRITICAL_NOTIFICATION),
+    ENUM(_KDE_NET_WM_WINDOW_TYPE_APPLET_POPUP),
     ENUM(_KDE_NET_WM_TEMPORARY_RULES),
     ENUM(_NET_WM_FRAME_OVERLAP),
     ENUM(_KDE_NET_WM_APPMENU_SERVICE_NAME),
@@ -154,6 +155,7 @@ ENUM_BEGIN(KwsAtom)
     // GTK extensions
     ENUM(_GTK_FRAME_EXTENTS),
     ENUM(_GTK_APPLICATION_ID),
+    ENUM(_GTK_SHOW_WINDOW_MENU),
 
     // application protocols
     ENUM(WM_PROTOCOLS),
